@@ -525,6 +525,23 @@ class DataClient(object):
         backbone.delete_classroom(uid)
         return
 
+    @staticmethod
+    def get_subject_num_map(school_id):
+        """
+        获取科目编号映射表
+        :param school_id:
+        :return:
+        """
+        backbone = Backbone(school_id)
+        backbone.wrap_subject_map()
+        return deepcopy(backbone.subject_map)
+
+    @staticmethod
+    def delete_subject(school_id, uid):
+        backbone = Backbone(school_id)
+        backbone.delete_subject(uid)
+        return
+
 
 class DataClientV1(DataClient):
     @staticmethod
