@@ -1,4 +1,5 @@
 import requests
+from ..settings import LIMIT_NUM
 
 
 class Requester(object):
@@ -139,7 +140,7 @@ class Requester(object):
         data = res.get('results', None) if isinstance(res, dict) else res
         return data
 
-    def wrap_map(self, func_name, key_names, value_name, limit=100):
+    def wrap_map(self, func_name, key_names, value_name, limit=int(LIMIT_NUM)):
         key_map = {}
         count, offset = None, 0
         while True:
