@@ -30,6 +30,7 @@ class CourseSync(BaseSync):
         self.course_table_managers = {}
         self.classroom_sign = {}
         self.class_sign = {}
+        self.student_section_map = {}
 
     def create_course_manager(self):
         """
@@ -85,11 +86,11 @@ class CourseSync(BaseSync):
     def extract_course(self):
         double_number_map = self.get_double_map()
         today, last_day = self.get_date_range()
-        today, last_day = '2020-09-02', '2020-10-11'
+        today, last_day = "2020-11-02", "2020-11-08"
         sql = "SELECT id, coursename, sectionid, classroomid, coursedate, weekday, userid, isteacher, deptname " \
               "FROM mid_attendschedule " \
-              "WHERE updateflag!=3 and coursedate > '{}' and coursedate <= '{}' and deptname!='学生' ORDER BY weekday".format(today,
-                                                                                                         last_day)
+              "WHERE updateflag!='3' and coursedate > '{}' and coursedate <= '{}' and deptname!='学生' " \
+              "ORDER BY weekday".format(today, last_day)
         self.cur.execute(sql)
         rows = self.cur.fetchall()
         for row in rows:
@@ -104,6 +105,8 @@ class CourseSync(BaseSync):
                 print("Can't Find SlotID {}".format(slot_id))
                 continue
             current_course_table = self.slot_course_table.get(slot_id)
+            if current_course_table[0] in ["M", "U"]:
+                print(current_course_table)
             if not current_course_table:
                 print("Can't Find SlotID {}".format(slot_id))
                 continue
@@ -123,7 +126,7 @@ class CourseSync(BaseSync):
                     course_name = self.create_unique_course_name(subject_name, class_name=class_name)
                     course_data = {'name': course_name, 'number': course_number, 'subject_number': subject_number,
                                    "subject_name": subject_name, 'classroom_number': classroom_number,
-                                   'is_walking': True, "teacher_number": None, "begin_week": 1, "end_week": 8,
+                                   'is_walking': True, "teacher_number": None, "begin_week": 1, "end_week": 1,
                                    'student_list': []}
                     course = CourseV2(**course_data)
                     # course.class_name = class_name
@@ -144,11 +147,24 @@ class CourseSync(BaseSync):
                     student_number = self.student_map.get(user_id)
                     if student_number:
                         course.add_student(student_number)
+                    class_name = self.student_section_map.get(student_number)
                     if class_name and class_name in self.class_name_num:
                         exist_class_sign = self.class_sign.get(class_name)
                         if exist_class_sign and current_course_table != exist_class_sign:
                             print("该班级{}已在{}课表出现，请检查数据".format(class_name, exist_class_sign))
                             continue
+                        if "E" in current_course_table and "小学" not in class_name:
+                            print("该班级{}已在{}课表出现，请检查数据".format(class_name, current_course_table))
+                            print(attend_id)
+                            continue
+                        if "M" in current_course_table and "初中" not in class_name:
+                            print("该班级{}已在{}课表出现，请检查数据".format(class_name, current_course_table))
+                            print(attend_id)
+                            continue
+                        if "U" in current_course_table and "高中" not in class_name:
+                            print("该班级{}已在{}课表出现，请检查数据".format(class_name, current_course_table))
+                            print(attend_id)
+                            continue
                         self.class_set[current_course_table].add(self.class_name_num[class_name])
                         self.class_sign[class_name] = current_course_table
                 course.add_position(num, week, category, classroom_number)
@@ -160,7 +176,7 @@ class CourseSync(BaseSync):
             logger.info("没有课程信息")
             return
         # begin_date, end_date = self.get_date_range(days=60)
-        course_table_name = "{}课表_{}".format(self.semester.name, str(uuid.uuid4())[:4])
+        # course_table_name = "{}课表_{}".format(self.semester.name, str(uuid.uuid4())[:4])
         # course_table_number = get_md5_hash(course_table_name)[:20]
         for course_table_name, course_table in self.course_table_managers.items():
             # course_table = CourseTableManagerV2(name=course_table_name, number=course_table_number,
