@@ -35,6 +35,6 @@ class TeacherSync(BaseSync):
         if not self.teacher_map:
             logger.info("没有老师信息")
             return
-        code, data = self.client.create_teacher(self.teacher_list)
-        logger.info("Code: {}, Msg: {}".format(code, data))
+        # code, data = self.client.create_teacher(self.teacher_list)
+        # logger.info("Code: {}, Msg: {}".format(code, data))
         self.close_db()
