@@ -33,13 +33,14 @@ def start_table_sync():
     course_sync.semester = schedule_sync.semester
     course_sync.rest_table = schedule_sync.rest_table
     course_sync.student_map = student_sync.student_map
+    course_sync.student_section_map = student_sync.student_section_map
     course_sync.teacher_map = teacher_sync.teacher_map
     course_sync.classroom_map = classroom_sync.classroom_map
     course_sync.class_name_num = section_sync.name_num
     course_sync.rest_table_slot = schedule_sync.rest_table_slot
     course_sync.start()
-    meeting_room_sync = MeetingRoomSync()
-    meeting_room_sync.start()
+    # meeting_room_sync = MeetingRoomSync()
+    # meeting_room_sync.start()
 
 
 def start_meeting_sync():
