@@ -96,4 +96,4 @@ class NiceRequester(Requester):
 
 
 nr = NiceRequester("3552", host="xgk.lanzhou.edu.cn/schoolscheduleserv/integration", protocol="https")
-nr.get_table()
+nr.get_school_list()
